"""
List of all MangaUpdates genres.
    * 'Action'
    * 'Adult'
    * 'Adventure'
    * 'Comedy'
    * 'Doujinshi'
    * 'Drama'
    * 'Ecchi'
    * 'Fantasy'
    * 'Gender Bender'
    * 'Harem'
    * 'Hentai'
    * 'Historical'
    * 'Horror'
    * 'Josei'
    * 'Lolicon'
    * 'Martial Arts'
    * 'Mature'
    * 'Mecha'
    * 'Mystery'
    * 'Psychological'
    * 'Romance'
    * 'School Life'
    * 'Sci-fi'
    * 'Seinen'
    * 'Shotacon'
    * 'Shoujo'
    * 'Shoujo Ai'
    * 'Shounen'
    * 'Shounen Ai'
    * 'Slice of Life'
    * 'Smut'
    * 'Sports'
    * 'Supernatural'
    * 'Tragedy'
    * 'Yaoi'
    * 'Yuri'
"""
genres = ['Action', 'Adult', 'Adventure', 'Comedy', 'Doujinshi', 'Drama', 'Ecchi', 'Fantasy', 'Gender Bender', 'Harem', 'Hentai', 'Historical', 'Horror', 'Josei', 'Lolicon', 'Martial Arts', 'Mature', 'Mecha', 'Mystery', 'Psychological', 'Romance', 'School Life', 'Sci-fi', 'Seinen', 'Shotacon', 'Shoujo', 'Shoujo Ai', 'Shounen', 'Shounen Ai', 'Slice of Life', 'Smut', 'Sports', 'Supernatural', 'Tragedy', 'Yaoi', 'Yuri']
